@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use JSON::PP;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub new {
     my ($class, %opts) = @_;
@@ -268,7 +268,7 @@ This module uses only core Perl modules:
 
 =head1 SEE ALSO
 
-L<jq>, L<JSON::XS>, L<JSON::PP>
+L<JSON::PP>
 
 =head1 AUTHOR
 
@@ -279,7 +279,3 @@ Kawamura Shingo <pannakoota1@gmail.com>
 Same as Perl itself.
 
 =cut
-
-Same as Perl itself.
-
-=cut
